Learn R Programming

bustt (version 0.1.0)

gt_as_dt: Get a dataframe with lubridate dates for the gtfs stop_times_df

Description

Get a dataframe with lubridate dates for the gtfs stop_times_df

Usage

gt_as_dt(stop_times_df)

Arguments

stop_times_df

a gtfsr$stop_times_df dataframe

Value

an dataframe with arrival and departure time set to lubridate types