most_frequent_service: Get the most frequent service for a set of trips.
Description
Get the most frequent service for a set of trips.
Usage
most_frequent_service(trips)
Arguments
trips
gtfs dataframe with a service_trips count column
Value
the trips that are in the most frequent service window